@@ -1,5 +1,7 @@
 package Moo::_Utils;
 
+no warnings 'once'; # guard against -w
+
 sub _getglob { \*{$_[0]} }
 sub _getstash { \%{"$_[0]::"} }
 
@@ -11,9 +13,14 @@ BEGIN {
 }
 
 use strictures 1;
+use Module::Runtime qw(require_module);
 use base qw(Exporter);
+use Moo::_mro;
 
-our @EXPORT = qw(_getglob _install_modifier _load_module _maybe_load_module);
+our @EXPORT = qw(
+    _getglob _install_modifier _load_module _maybe_load_module
+    _get_linear_isa
+);
 
 sub _install_modifier {
   my ($into, $type, $name, $code) = @_;
@@ -28,21 +35,20 @@ sub _install_modifier {
 
 our %MAYBE_LOADED;
 
-# _load_module is inlined in Role::Tiny - make sure to copy if you update it.
-
 sub _load_module {
   (my $proto = $_[0]) =~ s/::/\//g;
   return 1 if $INC{"${proto}.pm"};
   # can't just ->can('can') because a sub-package Foo::Bar::Baz
   # creates a 'Baz::' key in Foo::Bar's symbol table
   return 1 if grep !/::$/, keys %{_getstash($_[0])||{}};
-  require "${proto}.pm";
+  require_module($_[0]);
   return 1;
 }
 
 sub _maybe_load_module {
   return $MAYBE_LOADED{$_[0]} if exists $MAYBE_LOADED{$_[0]};
   (my $proto = $_[0]) =~ s/::/\//g;
+  local $@;
   if (eval { require "${proto}.pm"; 1 }) {
     $MAYBE_LOADED{$_[0]} = 1;
   } else {
@@ -54,4 +60,27 @@ sub _maybe_load_module {
   return $MAYBE_LOADED{$_[0]};
 }
 
+sub _get_linear_isa {
+    return mro::get_linear_isa($_[0]);
+}
+
+our $_in_global_destruction = 0;
+END { $_in_global_destruction = 1 }
+
+sub STANDARD_DESTROY {
+  my $self = shift;
+
+  my $e = do {
+    local $?;
+    local $@;
+    eval {
+      $self->DEMOLISHALL($_in_global_destruction);
+    };
+    $@;
+  };
+
+  no warnings 'misc';
+  die $e if $e; # rethrow
+}
+
 1;
